"""Headless core for the ATCMatch desktop notifier (no GUI imports)."""

from .core import (
    EVENT_NOTIFY_HORIZON_DAYS,
    Notification,
    PayloadValidationError,
)

__all__ = [
    "EVENT_NOTIFY_HORIZON_DAYS",
    "Notification",
    "PayloadValidationError",
]
