"""Package entry point.

Repo checkout: ``python -m tools.atcwatch``.  Installed (package directory
``atcwatch/`` under the install root on PYTHONPATH): ``python -m atcwatch``.
"""

from .atcwatch import main


raise SystemExit(main())
